Angular Grid - A Data Grid for AngularJS
Description: A high performance and feature rich data grid for AngularJS. This grid is faster than ui-grid and ng-grid.
Keywords: angularjs angular grid table ui-grid ng-grid

ag-Grid

##
The Best Javascript Data Grid

Feature rich, light weight, minimal footprint, no external dependencies.

People use ag-Grid over other free and paid grids because it's faster, more stable and better written.

Plain Javascript Angular 1.x
Angular 2.0 Web Components

## Install with Bower

bower install ag-grid

## Install with NPM

npm install angular-grid

## Download from Github

Angular Grid on Github

Column Pinning
Column Resizing
In Grid Sorting
Frozen / Floating Rows
Server Side Sorting
Data Editing
Keyboard Navigation
AngularJS Optional
Quick Search
In Grid Filtering
Server Side Filtering
Row Grouping
Row Aggregation
Column Grouping
Checkbox Selection
Grid Data Context
Expressions
Cell Styling
CSS Themes
Custom Rendering
Header Grouping
Events
Cross Browser
Printable
Grid API
Sorting API
Filtering API
Column API
Pagination
Infinite Scrolling
Floating Footers
Master / Slave

Using the default look and feel, get a feature rich grid with minimal coding.
Filtering and sorting work lightning fast despite 10,000 rows.
'Excel like' filtering (Name & Country columns) or customised filtering (Skills & Proficiency columns).
Example Large Data ({{rowCount}} rows)

Example Style for Presentations
Give a professional style for grids that will end up as presentations.
No scrolls works well for presentations and printing.

Cell renderers and grid themes allow customised behaviours and look and feels.
Create complex widgets, beyond what's expected of HTML tables.
Example Customisation
{{selectedFile}}